==> azureml_train_automl_client-1.9.0.post1-py3-none-any.whl: azureml/train/automl/_local_managed_utils.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""Utility methods used in local managed submission for automated ML in Azure Machine Learning."""
import logging
import os
from typing import Any, cast, Dict, List, Optional, Tuple

from azureml.train.automl import _logging
from azureml.train.automl._environment_utilities import modify_run_configuration
from azureml.train.automl.constants import _DataArgNames
from azureml.core import Environment
from azureml.core.workspace import Workspace
from azureml.data.abstract_dataset import AbstractDataset
from azureml.automl.core.shared.exceptions import DataException
try:
    from azureml.automl.core.shared.pickler import DefaultPickler
except ImportError:
    from azureml.automl.runtime.shared.pickler import DefaultPickler
has_pandas = False
has_numpy = False
try:
    import pandas as pd
    has_pandas = True
except ImportError:
    pass
try:
    import numpy as np
    has_numpy = True
except ImportError:
    pass

logger = logging.getLogger(__name__)


def get_data_args(workspace: Workspace, fit_params: Dict[str, Any], local_path: str) -> \
        Tuple[Dict[str, Any], List[str]]:
    """
    Extract data parameters, pickle them, and get args to pass to local managed script.
    This will either be Dataset IDs, or paths to pickle objects.
    """
    fit_params, data_dict = _extract_data(fit_params)
    dataset_args = _handle_data(workspace, data_dict, local_path)

    return fit_params, dataset_args


def _save_inmem(path: str, name: str, data: Any) -> str:
    file_name = name + ".pkl"
    file_path = os.path.join(path, file_name)
    pickler = DefaultPickler()
    pickler.dump(data, file_path)
    return file_name


def _compose_args(dataset_args: List[Any], name: str, data_type: str, value: Optional[Any]) -> List[Any]:
    arg = "--{}"
    arg_type = "--{}-dtype"

    if value is not None:
        dataset_args.append(arg.format(name))
        dataset_args.append(value)
        dataset_args.append(arg_type.format(name))
        dataset_args.append(data_type)

    return dataset_args


def _extract_data(fit_params: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
    """Remove data params from fit params."""
    data_dict = {_DataArgNames.X: fit_params.pop(_DataArgNames.X, None),
                 _DataArgNames.y: fit_params.pop(_DataArgNames.y, None),
                 _DataArgNames.sample_weight: fit_params.pop(_DataArgNames.sample_weight, None),
                 _DataArgNames.X_valid: fit_params.pop(_DataArgNames.X_valid, None),
                 _DataArgNames.y_valid: fit_params.pop(_DataArgNames.y_valid, None),
                 _DataArgNames.sample_weight_valid: fit_params.pop(_DataArgNames.sample_weight_valid, None),
                 _DataArgNames.training_data: fit_params.pop(_DataArgNames.training_data, None),
                 _DataArgNames.validation_data: fit_params.pop(_DataArgNames.validation_data, None)}
    return fit_params, data_dict


def _handle_data(workspace: Workspace,
                 data_dict: Dict[str, AbstractDataset],
                 local_path: str) -> List[Any]:
    """Register datasets and create script arguments to pass to the child job."""
    dataset_args = []  # type: List[Any]
    for data_name, data_value in data_dict.items():
        if isinstance(data_value, AbstractDataset):
            # ScriptRunConfig will translate the DatasetConsumptionConfig into a dataset id
            dataset_args = _compose_args(dataset_args,
                                         data_name,
                                         "dataset",
                                         data_value.as_named_input(data_name))
        elif isinstance(data_value, pd.DataFrame):
            dataset_args = _compose_args(dataset_args,
                                         data_name,
                                         "pandas",
                                         _save_inmem(local_path, data_name, data_value))
        elif isinstance(data_value, np.ndarray):
            dataset_args = _compose_args(dataset_args,
                                         data_name,
                                         "numpy",
                                         _save_inmem(local_path, data_name, data_value))
        elif data_value is not None:
            raise DataException("Received unrecognized type for {}. Data should be a DataSet, a Pandas DataFrame"
                                "or a Numpy array.".format(data_name))
    return dataset_args


def modify_managed_run_config(run_config, parent_run, experiment, settings_obj):
    _logging.set_run_custom_dimensions(
        automl_settings=settings_obj,
        parent_run_id=parent_run.id,
        child_run_id=None)
    properties = parent_run.get_properties()
    env_name = properties.get("environment_cpu_name")
    env_version = properties.get("environment_cpu_version")
    if env_version == "":
        env_version = None
    logger.info("Running local managed run on curated environment: {} version: {}".format(env_name, env_version))

    if env_name is None or env_name is "":
        run_config.environment.python.user_managed_dependencies = False
        run_config = modify_run_configuration(settings_obj, run_config, logger)
    else:
        run_config.environment = Environment.get(experiment.workspace, env_name, env_version)

    return run_config

==> azureml_train_automl_client-1.10.0-py3-none-any.whl: azureml/train/automl/_local_managed_utils.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""Utility methods used in local managed submission for automated ML in Azure Machine Learning."""
import logging
import os
import subprocess
from typing import Any, cast, Dict, List, Optional, Tuple

from azureml.train.automl import _logging
from azureml.train.automl._environment_utilities import modify_run_configuration
from azureml.train.automl.constants import _DataArgNames
from azureml.core import Environment
from azureml.core.workspace import Workspace
from azureml.data.abstract_dataset import AbstractDataset
from azureml.automl.core.shared.exceptions import DataException
from azureml.automl.core.shared.pickler import DefaultPickler


logger = logging.getLogger(__name__)


def get_data_args(workspace: Workspace, fit_params: Dict[str, Any], local_path: str) -> \
        Tuple[Dict[str, Any], List[str]]:
    """
    Extract data parameters, pickle them, and get args to pass to local managed script.
    This will either be Dataset IDs, or paths to pickle objects.
    """
    fit_params, data_dict = _extract_data(fit_params)
    dataset_args = _handle_data(data_dict, local_path)

    return fit_params, dataset_args


def _save_inmem(path: str, name: str, data: Any) -> str:
    file_name = name + ".pkl"
    file_path = os.path.join(path, file_name)
    pickler = DefaultPickler()
    pickler.dump(data, file_path)
    return file_name


def _compose_args(dataset_args: List[Any], name: str, data_type: str, value: Optional[Any]) -> List[Any]:
    arg = "--{}"
    arg_type = "--{}-dtype"

    if value is not None:
        dataset_args.append(arg.format(name))
        dataset_args.append(value)
        dataset_args.append(arg_type.format(name))
        dataset_args.append(data_type)

    return dataset_args


def _extract_data(fit_params: Dict[str, Any]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
    """Remove data params from fit params."""
    data_dict = {_DataArgNames.X: fit_params.pop(_DataArgNames.X, None),
                 _DataArgNames.y: fit_params.pop(_DataArgNames.y, None),
                 _DataArgNames.sample_weight: fit_params.pop(_DataArgNames.sample_weight, None),
                 _DataArgNames.X_valid: fit_params.pop(_DataArgNames.X_valid, None),
                 _DataArgNames.y_valid: fit_params.pop(_DataArgNames.y_valid, None),
                 _DataArgNames.sample_weight_valid: fit_params.pop(_DataArgNames.sample_weight_valid, None),
                 _DataArgNames.training_data: fit_params.pop(_DataArgNames.training_data, None),
                 _DataArgNames.validation_data: fit_params.pop(_DataArgNames.validation_data, None)}
    return fit_params, data_dict


def _handle_data(data_dict: Dict[str, AbstractDataset],
                 local_path: str) -> List[Any]:
    """Register datasets and create script arguments to pass to the child job."""
    has_pandas = False
    has_numpy = False
    try:
        import pandas as pd
        has_pandas = True
    except ImportError:
        pass
    try:
        import numpy as np
        has_numpy = True
    except ImportError:
        pass
    logger.info("Pandas present: {}. Numpy present: {}".format(has_pandas, has_numpy))
    dataset_args = []  # type: List[Any]
    for data_name, data_value in data_dict.items():
        if isinstance(data_value, AbstractDataset):
            logger.info("Saving Dataset for script run submission.")
            # ScriptRunConfig will translate the DatasetConsumptionConfig into a dataset id
            dataset_args = _compose_args(dataset_args,
                                         data_name,
                                         "dataset",
                                         data_value.as_named_input(data_name))
        elif has_pandas and isinstance(data_value, pd.DataFrame):
            logger.info("Saving Pandas for script run submission.")
            dataset_args = _compose_args(dataset_args,
                                         data_name,
                                         "pandas",
                                         _save_inmem(local_path, data_name, data_value))
        elif has_numpy and isinstance(data_value, np.ndarray):
            logger.info("Saving Numpy for script run submission.")
            dataset_args = _compose_args(dataset_args,
                                         data_name,
                                         "numpy",
                                         _save_inmem(local_path, data_name, data_value))
        elif data_value is not None:
            raise DataException("Received unrecognized type for {}. Data should be a DataSet, a Pandas DataFrame"
                                "or a Numpy array.".format(data_name))
    return dataset_args


def modify_managed_run_config(run_config, parent_run, experiment, settings_obj):
    _logging.set_run_custom_dimensions(
        automl_settings=settings_obj,
        parent_run_id=parent_run.id,
        child_run_id=None)
    properties = parent_run.get_properties()
    env_name = properties.get("environment_cpu_name")
    env_version = properties.get("environment_cpu_version")
    if env_version == "":
        env_version = None
    logger.info("Running local managed run on curated environment: {} version: {}".format(env_name, env_version))

    if env_name is None or env_name is "":
        run_config.environment.python.user_managed_dependencies = False
        run_config = modify_run_configuration(settings_obj, run_config, logger)
    else:
        run_config.environment = Environment.get(experiment.workspace, env_name, env_version)

    return run_config


def is_docker_installed() -> bool:
    try:
        version = subprocess.check_output(["docker", "--version"]).decode('utf8')
        logger.info("Docker is installed with {}.".format(version))
    except Exception:
        logger.info("Docker is not installed.")
        return False
    return True
